@@ -30,6 +30,7 @@ import org.openhab.core.config.core.dto.XmlConfigDescriptionRef;
  *         &lt;element name="label" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
  *         &lt;element name="description" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
  *         &lt;element name="category" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
+ *         &lt;element name="semantic-equipment-tag" type="{https://openhab.org/schemas/thing-description/v1.0.0}semanticEquipmentTag" minOccurs="0"/&gt;
  *         &lt;choice minOccurs="0"&gt;
  *           &lt;element name="channels" type="{https://openhab.org/schemas/thing-description/v1.0.0}channels"/&gt;
  *           &lt;element name="channel-groups" type="{https://openhab.org/schemas/thing-description/v1.0.0}channelGroups"/&gt;
@@ -57,6 +58,7 @@ import org.openhab.core.config.core.dto.XmlConfigDescriptionRef;
     "label",
     "description",
     "category",
+    "semanticEquipmentTag",
     "channels",
     "channelGroups",
     "properties",
@@ -67,52 +69,55 @@ import org.openhab.core.config.core.dto.XmlConfigDescriptionRef;
 @XmlSeeAlso({
     XmlBridgeType.class
 })
-@Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+@Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
 public class XmlThingType implements Serializable
 {
 
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     private final static long serialVersionUID = 1L;
     @XmlElementWrapper(name = "supported-bridge-type-refs")
     @XmlElement(name = "bridge-type-ref")
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     protected List<XmlBridgeTypeRef> supportedBridgeTypeRefs = new ArrayList<XmlBridgeTypeRef>();
     @XmlElement(required = true)
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     protected String label;
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     protected String description;
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     protected String category;
+    @XmlElement(name = "semantic-equipment-tag")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
+    protected String semanticEquipmentTag;
     @XmlElementWrapper
     @XmlElement(name = "channel")
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     protected List<XmlChannel> channels = new ArrayList<XmlChannel>();
     @XmlElementWrapper(name = "channel-groups")
     @XmlElement(name = "channel-group")
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     protected List<XmlChannelGroup> channelGroups = new ArrayList<XmlChannelGroup>();
     @XmlElementWrapper
     @XmlElement(name = "property")
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     protected List<XmlProperty> properties = new ArrayList<XmlProperty>();
     @XmlElement(name = "representation-property")
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     protected String representationProperty;
     @XmlElement(name = "config-description")
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     protected XmlConfigDescription configDescription;
     @XmlElement(name = "config-description-ref")
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     protected XmlConfigDescriptionRef configDescriptionRef;
     @XmlAttribute(name = "id", required = true)
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     protected String id;
     @XmlAttribute(name = "listed")
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     protected Boolean listed;
     @XmlAttribute(name = "extensible")
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     protected String extensible;
 
     /**
@@ -123,7 +128,7 @@ public class XmlThingType implements Serializable
      *     {@link String }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public String getLabel() {
         return label;
     }
@@ -136,7 +141,7 @@ public class XmlThingType implements Serializable
      *     {@link String }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public void setLabel(String value) {
         this.label = value;
     }
@@ -149,7 +154,7 @@ public class XmlThingType implements Serializable
      *     {@link String }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public String getDescription() {
         return description;
     }
@@ -162,7 +167,7 @@ public class XmlThingType implements Serializable
      *     {@link String }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public void setDescription(String value) {
         this.description = value;
     }
@@ -175,7 +180,7 @@ public class XmlThingType implements Serializable
      *     {@link String }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public String getCategory() {
         return category;
     }
@@ -188,11 +193,37 @@ public class XmlThingType implements Serializable
      *     {@link String }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public void setCategory(String value) {
         this.category = value;
     }
 
+    /**
+     * Gets the value of the semanticEquipmentTag property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
+    public String getSemanticEquipmentTag() {
+        return semanticEquipmentTag;
+    }
+
+    /**
+     * Sets the value of the semanticEquipmentTag property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
+    public void setSemanticEquipmentTag(String value) {
+        this.semanticEquipmentTag = value;
+    }
+
     /**
      * Gets the value of the representationProperty property.
      * 
@@ -201,7 +232,7 @@ public class XmlThingType implements Serializable
      *     {@link String }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public String getRepresentationProperty() {
         return representationProperty;
     }
@@ -214,7 +245,7 @@ public class XmlThingType implements Serializable
      *     {@link String }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public void setRepresentationProperty(String value) {
         this.representationProperty = value;
     }
@@ -227,7 +258,7 @@ public class XmlThingType implements Serializable
      *     {@link XmlConfigDescription }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public XmlConfigDescription getConfigDescription() {
         return configDescription;
     }
@@ -240,7 +271,7 @@ public class XmlThingType implements Serializable
      *     {@link XmlConfigDescription }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public void setConfigDescription(XmlConfigDescription value) {
         this.configDescription = value;
     }
@@ -253,7 +284,7 @@ public class XmlThingType implements Serializable
      *     {@link XmlConfigDescriptionRef }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public XmlConfigDescriptionRef getConfigDescriptionRef() {
         return configDescriptionRef;
     }
@@ -266,7 +297,7 @@ public class XmlThingType implements Serializable
      *     {@link XmlConfigDescriptionRef }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public void setConfigDescriptionRef(XmlConfigDescriptionRef value) {
         this.configDescriptionRef = value;
     }
@@ -279,7 +310,7 @@ public class XmlThingType implements Serializable
      *     {@link String }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public String getId() {
         return id;
     }
@@ -292,7 +323,7 @@ public class XmlThingType implements Serializable
      *     {@link String }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public void setId(String value) {
         this.id = value;
     }
@@ -305,7 +336,7 @@ public class XmlThingType implements Serializable
      *     {@link Boolean }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public boolean isListed() {
         if (listed == null) {
             return true;
@@ -322,7 +353,7 @@ public class XmlThingType implements Serializable
      *     {@link Boolean }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public void setListed(Boolean value) {
         this.listed = value;
     }
@@ -335,7 +366,7 @@ public class XmlThingType implements Serializable
      *     {@link String }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public String getExtensible() {
         return extensible;
     }
@@ -348,47 +379,47 @@ public class XmlThingType implements Serializable
      *     {@link String }
      *     
      */
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public void setExtensible(String value) {
         this.extensible = value;
     }
 
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public List<XmlBridgeTypeRef> getSupportedBridgeTypeRefs() {
         return supportedBridgeTypeRefs;
     }
 
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public void setSupportedBridgeTypeRefs(List<XmlBridgeTypeRef> supportedBridgeTypeRefs) {
         this.supportedBridgeTypeRefs = supportedBridgeTypeRefs;
     }
 
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public List<XmlChannel> getChannels() {
         return channels;
     }
 
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public void setChannels(List<XmlChannel> channels) {
         this.channels = channels;
     }
 
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public List<XmlChannelGroup> getChannelGroups() {
         return channelGroups;
     }
 
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public void setChannelGroups(List<XmlChannelGroup> channelGroups) {
         this.channelGroups = channelGroups;
     }
 
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public List<XmlProperty> getProperties() {
         return properties;
     }
 
-    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-06T14:14:48Z")
+    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
     public void setProperties(List<XmlProperty> properties) {
         this.properties = properties;
     }
